# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/signature.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/signature.proto',
  package='google.api',
  syntax='proto3',
  serialized_options=_b('\n\016com.google.apiB\016SignatureProtoP\001'),
  serialized_pb=_b('\n\x1agoogle/api/signature.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto\"t\n\x0fMethodSignature\x12\x0e\n\x06\x66ields\x18\x01 \x03(\t\x12\x15\n\rfunction_name\x18\x02 \x01(\t\x12:\n\x15\x61\x64\x64itional_signatures\x18\x03 \x03(\x0b\x32\x1b.google.api.MethodSignature:V\n\x10method_signature\x12\x1e.google.protobuf.MethodOptions\x18\x9b\x08 \x01(\x0b\x32\x1b.google.api.MethodSignature:0\n\x08required\x12\x1d.google.protobuf.FieldOptions\x18\x9c\x08 \x01(\x08\x42\"\n\x0e\x63om.google.apiB\x0eSignatureProtoP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


METHOD_SIGNATURE_FIELD_NUMBER = 1051
method_signature = _descriptor.FieldDescriptor(
  name='method_signature', full_name='google.api.method_signature', index=0,
  number=1051, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
REQUIRED_FIELD_NUMBER = 1052
required = _descriptor.FieldDescriptor(
  name='required', full_name='google.api.required', index=1,
  number=1052, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_METHODSIGNATURE = _descriptor.Descriptor(
  name='MethodSignature',
  full_name='google.api.MethodSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='google.api.MethodSignature.fields', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_name', full_name='google.api.MethodSignature.function_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_signatures', full_name='google.api.MethodSignature.additional_signatures', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=192,
)

_METHODSIGNATURE.fields_by_name['additional_signatures'].message_type = _METHODSIGNATURE
DESCRIPTOR.message_types_by_name['MethodSignature'] = _METHODSIGNATURE
DESCRIPTOR.extensions_by_name['method_signature'] = method_signature
DESCRIPTOR.extensions_by_name['required'] = required
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MethodSignature = _reflection.GeneratedProtocolMessageType('MethodSignature', (_message.Message,), dict(
  DESCRIPTOR = _METHODSIGNATURE,
  __module__ = 'google.api.signature_pb2'
  # @@protoc_insertion_point(class_scope:google.api.MethodSignature)
  ))
_sym_db.RegisterMessage(MethodSignature)

method_signature.message_type = _METHODSIGNATURE
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_signature)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(required)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
