# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/retry.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.rpc import code_pb2 as google_dot_rpc_dot_code__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/retry.proto',
  package='google.api',
  syntax='proto3',
  serialized_options=_b('\n\016com.google.apiB\nRetryProtoP\001'),
  serialized_pb=_b('\n\x16google/api/retry.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto\x1a\x15google/rpc/code.proto\"(\n\x05Retry\x12\x1f\n\x05\x63odes\x18\x01 \x03(\x0e\x32\x10.google.rpc.Code:A\n\x05retry\x12\x1e.google.protobuf.MethodOptions\x18\xa0\x08 \x01(\x0b\x32\x11.google.api.RetryB\x1e\n\x0e\x63om.google.apiB\nRetryProtoP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,google_dot_rpc_dot_code__pb2.DESCRIPTOR,])


RETRY_FIELD_NUMBER = 1056
retry = _descriptor.FieldDescriptor(
  name='retry', full_name='google.api.retry', index=0,
  number=1056, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_RETRY = _descriptor.Descriptor(
  name='Retry',
  full_name='google.api.Retry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='codes', full_name='google.api.Retry.codes', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=135,
)

_RETRY.fields_by_name['codes'].enum_type = google_dot_rpc_dot_code__pb2._CODE
DESCRIPTOR.message_types_by_name['Retry'] = _RETRY
DESCRIPTOR.extensions_by_name['retry'] = retry
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Retry = _reflection.GeneratedProtocolMessageType('Retry', (_message.Message,), dict(
  DESCRIPTOR = _RETRY,
  __module__ = 'google.api.retry_pb2'
  # @@protoc_insertion_point(class_scope:google.api.Retry)
  ))
_sym_db.RegisterMessage(Retry)

retry.message_type = _RETRY
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(retry)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
