# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/metadata.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import auth_pb2 as google_dot_api_dot_auth__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/metadata.proto',
  package='google.api',
  syntax='proto3',
  serialized_options=_b('\n\016com.google.apiB\rMetadataProtoP\001'),
  serialized_pb=_b('\n\x19google/api/metadata.proto\x12\ngoogle.api\x1a\x15google/api/auth.proto\x1a google/protobuf/descriptor.proto\"f\n\x08Metadata\x12\x14\n\x0cproduct_name\x18\x01 \x01(\t\x12\x13\n\x0bproduct_url\x18\x02 \x01(\t\x12\x14\n\x0cpackage_name\x18\x03 \x01(\t\x12\x19\n\x11package_namespace\x18\x04 \x03(\t:E\n\x08metadata\x12\x1c.google.protobuf.FileOptions\x18\x98\x08 \x01(\x0b\x32\x14.google.api.Metadata:6\n\x0c\x64\x65\x66\x61ult_host\x12\x1f.google.protobuf.ServiceOptions\x18\x99\x08 \x01(\t:N\n\x05oauth\x12\x1f.google.protobuf.ServiceOptions\x18\x9a\x08 \x01(\x0b\x32\x1d.google.api.OAuthRequirementsB!\n\x0e\x63om.google.apiB\rMetadataProtoP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_api_dot_auth__pb2.DESCRIPTOR,google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


METADATA_FIELD_NUMBER = 1048
metadata = _descriptor.FieldDescriptor(
  name='metadata', full_name='google.api.metadata', index=0,
  number=1048, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
DEFAULT_HOST_FIELD_NUMBER = 1049
default_host = _descriptor.FieldDescriptor(
  name='default_host', full_name='google.api.default_host', index=1,
  number=1049, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=_b("").decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
OAUTH_FIELD_NUMBER = 1050
oauth = _descriptor.FieldDescriptor(
  name='oauth', full_name='google.api.oauth', index=2,
  number=1050, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='google.api.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='product_name', full_name='google.api.Metadata.product_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_url', full_name='google.api.Metadata.product_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='package_name', full_name='google.api.Metadata.package_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='package_namespace', full_name='google.api.Metadata.package_namespace', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=200,
)

DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA
DESCRIPTOR.extensions_by_name['metadata'] = metadata
DESCRIPTOR.extensions_by_name['default_host'] = default_host
DESCRIPTOR.extensions_by_name['oauth'] = oauth
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), dict(
  DESCRIPTOR = _METADATA,
  __module__ = 'google.api.metadata_pb2'
  # @@protoc_insertion_point(class_scope:google.api.Metadata)
  ))
_sym_db.RegisterMessage(Metadata)

metadata.message_type = _METADATA
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(metadata)
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(default_host)
oauth.message_type = google_dot_api_dot_auth__pb2._OAUTHREQUIREMENTS
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(oauth)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
