# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/resources.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/resources.proto',
  package='google.api',
  syntax='proto3',
  serialized_options=_b('\n\016com.google.apiB\016ResourcesProtoP\001'),
  serialized_pb=_b('\n\x1agoogle/api/resources.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto\"+\n\x08Resource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tbase_name\x18\x02 \x01(\t\"I\n\x0bResourceSet\x12\x11\n\tbase_name\x18\x01 \x01(\t\x12\'\n\tresources\x18\x02 \x03(\x0b\x32\x14.google.api.Resource\"(\n\x07Project\x12\x1d\n\x04name\x18\x01 \x01(\tB\x0f\xea\x41\x0c\n\nprojects/*\"2\n\x0cOrganization\x12\"\n\x04name\x18\x01 \x01(\tB\x14\xea\x41\x11\n\x0forganizations/*:F\n\x08resource\x12\x1d.google.protobuf.FieldOptions\x18\x9d\x08 \x01(\x0b\x32\x14.google.api.Resource:M\n\x0cresource_set\x12\x1d.google.protobuf.FieldOptions\x18\x9e\x08 \x01(\x0b\x32\x17.google.api.ResourceSet:5\n\rresource_type\x12\x1d.google.protobuf.FieldOptions\x18\x9f\x08 \x01(\tB\"\n\x0e\x63om.google.apiB\x0eResourcesProtoP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


RESOURCE_FIELD_NUMBER = 1053
resource = _descriptor.FieldDescriptor(
  name='resource', full_name='google.api.resource', index=0,
  number=1053, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
RESOURCE_SET_FIELD_NUMBER = 1054
resource_set = _descriptor.FieldDescriptor(
  name='resource_set', full_name='google.api.resource_set', index=1,
  number=1054, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
RESOURCE_TYPE_FIELD_NUMBER = 1055
resource_type = _descriptor.FieldDescriptor(
  name='resource_type', full_name='google.api.resource_type', index=2,
  number=1055, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=_b("").decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='google.api.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='google.api.Resource.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_name', full_name='google.api.Resource.base_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=119,
)


_RESOURCESET = _descriptor.Descriptor(
  name='ResourceSet',
  full_name='google.api.ResourceSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_name', full_name='google.api.ResourceSet.base_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources', full_name='google.api.ResourceSet.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=194,
)


_PROJECT = _descriptor.Descriptor(
  name='Project',
  full_name='google.api.Project',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.Project.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\352A\014\n\nprojects/*'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=236,
)


_ORGANIZATION = _descriptor.Descriptor(
  name='Organization',
  full_name='google.api.Organization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.Organization.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\352A\021\n\017organizations/*'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=288,
)

_RESOURCESET.fields_by_name['resources'].message_type = _RESOURCE
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
DESCRIPTOR.message_types_by_name['ResourceSet'] = _RESOURCESET
DESCRIPTOR.message_types_by_name['Project'] = _PROJECT
DESCRIPTOR.message_types_by_name['Organization'] = _ORGANIZATION
DESCRIPTOR.extensions_by_name['resource'] = resource
DESCRIPTOR.extensions_by_name['resource_set'] = resource_set
DESCRIPTOR.extensions_by_name['resource_type'] = resource_type
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), dict(
  DESCRIPTOR = _RESOURCE,
  __module__ = 'google.api.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.Resource)
  ))
_sym_db.RegisterMessage(Resource)

ResourceSet = _reflection.GeneratedProtocolMessageType('ResourceSet', (_message.Message,), dict(
  DESCRIPTOR = _RESOURCESET,
  __module__ = 'google.api.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.ResourceSet)
  ))
_sym_db.RegisterMessage(ResourceSet)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), dict(
  DESCRIPTOR = _PROJECT,
  __module__ = 'google.api.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.Project)
  ))
_sym_db.RegisterMessage(Project)

Organization = _reflection.GeneratedProtocolMessageType('Organization', (_message.Message,), dict(
  DESCRIPTOR = _ORGANIZATION,
  __module__ = 'google.api.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.Organization)
  ))
_sym_db.RegisterMessage(Organization)

resource.message_type = _RESOURCE
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(resource)
resource_set.message_type = _RESOURCESET
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(resource_set)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(resource_type)

DESCRIPTOR._options = None
_PROJECT.fields_by_name['name']._options = None
_ORGANIZATION.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
